@@ -514,7 +514,12 @@ def map_config_to_obj(want, module):
                 intf_type = get_interface_type(w['name'])
 
                 if intf_type in ['portchannel', 'ethernet']:
-                    if not interface_table.get('eth_mode'):
+                    mode = interface_table.get('eth_mode')
+                    if mode in ('access', 'trunk', 'dot1q-tunnel'):
+                        obj['mode'] = 'layer2'
+                    elif mode in ('routed', 'layer3'):
+                        obj['mode'] = 'layer3'
+                    else:
                         obj['mode'] = 'layer3'
 
                 if intf_type == 'ethernet':
@@ -524,11 +529,6 @@ def map_config_to_obj(want, module):
                     obj['mtu'] = interface_table.get('eth_mtu')
                     obj['duplex'] = interface_table.get('eth_duplex')
                     speed = interface_table.get('eth_speed')
-                    mode = interface_table.get('eth_mode')
-                    if mode in ('access', 'trunk'):
-                        obj['mode'] = 'layer2'
-                    elif mode in ('routed', 'layer3'):
-                        obj['mode'] = 'layer3'
 
                     command = 'show run interface {0}'.format(obj['name'])
                     body = execute_show_command(command, module)[0]
@@ -557,6 +557,7 @@ def map_config_to_obj(want, module):
                                                             'nxapibug'))
                     obj['description'] = str(attributes.get('description',
                                                             'nxapi_bug'))
+                    obj['mtu'] = interface_table.get('svi_mtu')
 
                     command = 'show run interface {0}'.format(obj['name'])
                     body = execute_show_command(command, module)[0]
@@ -578,7 +579,7 @@ def map_config_to_obj(want, module):
                     obj['name'] = normalize_interface(interface_table.get('interface'))
                     obj['admin_state'] = interface_table.get('admin_state')
                     obj['description'] = interface_table.get('desc')
-                    obj['mode'] = interface_table.get('eth_mode')
+                    obj['mtu'] = interface_table.get('eth_mtu')
 
         objs.append(obj)
 
